Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/bmesh/intern/bmesh_queries.c')
-rw-r--r--source/blender/bmesh/intern/bmesh_queries.c22
1 files changed, 11 insertions, 11 deletions
diff --git a/source/blender/bmesh/intern/bmesh_queries.c b/source/blender/bmesh/intern/bmesh_queries.c
index cc9dfe1701b..341bb877f93 100644
--- a/source/blender/bmesh/intern/bmesh_queries.c
+++ b/source/blender/bmesh/intern/bmesh_queries.c
@@ -482,7 +482,7 @@ int BM_edge_is_manifold(BMesh *UNUSED(bm), BMEdge *e)
* of a shell (has one face associated with it)
*/
-#if 1 /* fast path for checking boundry */
+#if 1 /* fast path for checking boundary */
int BM_edge_is_boundary(BMEdge *e)
{
const BMLoop *l = e->l;
@@ -595,7 +595,7 @@ BMLoop *BM_face_vert_share_loop(BMFace *f, BMVert *v)
* Returns the verts of an edge as used in a face
* if used in a face at all, otherwise just assign as used in the edge.
*
- * Useful to get a determanistic winding order when calling
+ * Useful to get a deterministic winding order when calling
* BM_face_create_ngon() on an arbitrary array of verts,
* though be sure to pick an edge which has a face.
*/
@@ -680,7 +680,7 @@ void BM_loop_face_tangent(BMesh *UNUSED(bm), BMLoop *l, float r_tangent[3])
cross_v3_v3v3(r_tangent, dir, nor);
}
else {
- /* prev/next are the same - compare with face normal since we dont have one */
+ /* prev/next are the same - compare with face normal since we don't have one */
cross_v3_v3v3(r_tangent, v_next, l->f->no);
}
@@ -861,7 +861,7 @@ int BM_face_exists_multi(BMesh *bm, BMVert **varr, BMEdge **earr, int len)
}
}
/* now tag all verts and edges in the boundry array as true so
* we can know if a face-vert is from our array */
for (i = 0; i < len; i++) {
BM_elem_flag_enable(varr[i], BM_ELEM_INTERNAL_TAG);
@@ -869,10 +869,10 @@ int BM_face_exists_multi(BMesh *bm, BMVert **varr, BMEdge **earr, int len)
}
/* so! boundry is tagged, everything else cleared */
/* 1) tag all faces connected to edges - if all their verts are boundry */
tot_tag = 0;
for (i = 0; i < len; i++) {
BM_ITER(f, &fiter, bm, BM_FACES_OF_EDGE, earr[i]) {
@@ -886,7 +886,7 @@ int BM_face_exists_multi(BMesh *bm, BMVert **varr, BMEdge **earr, int len)
}
if (ok) {
/* we only use boundry verts */
BM_elem_flag_enable(f, BM_ELEM_INTERNAL_TAG);
tot_tag++;
}
@@ -898,19 +898,19 @@ int BM_face_exists_multi(BMesh *bm, BMVert **varr, BMEdge **earr, int len)
}
if (tot_tag == 0) {
/* no faces use only boundry verts, quit early */
return FALSE;
}
/* 2) loop over non-boundry edges that use boundry verts,
* check each have 2 tagges faces connected (faces that only use 'varr' verts) */
ok = TRUE;
for (i = 0; i < len; i++) {
BM_ITER(e, &fiter, bm, BM_EDGES_OF_VERT, varr[i]) {
- if (/* non-boundry edge */
+ if (/* non-boundary edge */
BM_elem_flag_test(e, BM_ELEM_INTERNAL_TAG) == FALSE &&
- /* ...using boundry verts */
+ /* ...using boundary verts */
BM_elem_flag_test(e->v1, BM_ELEM_INTERNAL_TAG) == TRUE &&
BM_elem_flag_test(e->v2, BM_ELEM_INTERNAL_TAG) == TRUE)
{
@@ -861,7 +861,7 @@ int BM_face_exists_multi(BMesh *bm, BMVert **varr, BMEdge **earr, int len)
}
}
- /* now tag all verts and edges in the boundry array as true so
+ /* now tag all verts and edges in the boundary array as true so
* we can know if a face-vert is from our array */
for (i = 0; i < len; i++) {
@@ -869,10 +869,10 @@ int BM_face_exists_multi(BMesh *bm, BMVert **varr, BMEdge **earr, int len)
}
- /* so! boundry is tagged, everything else cleared */
+ /* so! boundary is tagged, everything else cleared */
- /* 1) tag all faces connected to edges - if all their verts are boundry */
+ /* 1) tag all faces connected to edges - if all their verts are boundary */
tot_tag = 0;
for (i = 0; i < len; i++) {
@@ -886,7 +886,7 @@ int BM_face_exists_multi(BMesh *bm, BMVert **varr, BMEdge **earr, int len)
}
if (ok) {
- /* we only use boundry verts */
+ /* we only use boundary verts */
BM_elem_flag_enable(f, BM_ELEM_INTERNAL_TAG);
tot_tag++;
@@ -898,19 +898,19 @@ int BM_face_exists_multi(BMesh *bm, BMVert **varr, BMEdge **earr, int len)
}
if (tot_tag == 0) {
- /* no faces use only boundry verts, quit early */
+ /* no faces use only boundary verts, quit early */
return FALSE;
}
@@ -898,19 +898,19 @@ int BM_face_exists_multi(BMesh *bm, BMVert **varr, BMEdge **earr, int len)
return FALSE;
}
- /* 2) loop over non-boundry edges that use boundry verts,
+ /* 2) loop over non-boundary edges that use boundary verts,
* check each have 2 tagges faces connected (faces that only use 'varr' verts) */
ok = TRUE;